function varargout=configure(varargin)
% FUNCTION fc_oogmsh.configure()
%   Configures the toolbox/package by setting gmsh path, meshes default 
%   directory and .geo files default directory.
%   Theses informations will be stored in ... file.
%
% <COPYRIGHT>
  [conffile,isFileExists]=fc_graphics4mesh.getLocalConfFile();
  fullname=mfilename('fullpath');
  I=strfind(fullname,filesep);
  Path=fullname(1:(I(end-1)-1));
  if isFileExists
    run(conffile);
  else
    data_dir=[Path,filesep,'data'];
    fc_tools_dir=''; % empty if pkg or toolbox in path
  end
  p = inputParser;
  p.addParamValue('data_dir',data_dir,@ischar);
  p.addParamValue('fc_tools_dir',fc_tools_dir,@ischar);
  %p.addParamValue('force',false,@islogical); 
  p.parse(varargin{:});
  R=p.Results;
  
  if ~isdir(R.data_dir), error('Not a directory :\n''data_dir''=%s\n', R.data_dir); end
  
  fc_tools_dir=get_tbxpath('tools','hypermesh',R.fc_tools_dir);
  
  fprintf('Write in %s ...\n',conffile);
  fid=fopen(conffile,'w');
  if (fid==0), error('Unable to open file :\n %s\n',conffile);end
  fprintf(fid,'%% Automaticaly generated with fc_graphics4mesh.configure()\n');
  fprintf(fid,'data_dir=''%s'';\n',R.data_dir);
  fprintf(fid,'fc_tools_dir=''%s'';\n',fc_tools_dir);
  fclose(fid);
  fprintf('  -> done\n');
  if nargout==1,varargout{1}=conffile;end
  rehash
end


%
% DO NOT MODIFY THIS FUNCTION: IT IS AUTOMATICALLY ADDED
%
function tbxpath=get_tbxpath(tbxname,tbxfrom,givenpath,varargin) % tbxname is the toolbox to 'include' in the toolbox <tbxfrom>
  p = inputParser;
  p.addParamValue('stop'   ,true,@islogical);
  p.parse(varargin{:});
  stop=p.Results.stop;
  tbxpath='';
  if ~isempty(givenpath) 
    if ~isdir(givenpath) 
      fprintf('[fc-%s] The given path does not exists:\n   -> %s\n',tbxfrom,tbxname,givenpath)
      fprintf('[fc-%s] Use fc_%s.configure(''fc_%s_dir'',<DIR>) to correct this issue\n\n',tbxfrom,tbxfrom,tbxname);
      if stop
        error(sprintf('fc-%s::configure',tbxfrom))
      else
        warning(sprintf('fc-%s::configure',tbxfrom))
      end
    end
    tbxpath=givenpath;
    addpath(tbxpath);rehash path;
    failed=false;
    try % check if the toolbox can be found
      eval(sprintf('fc_%s.version();',tbxname))
    catch
      fprintf('[fc-%s] Unable to load the fc-%s toolbox/package in given path:\n  %s\n',tbxfrom,tbxname,tbxpath)
      if stop
        error(sprintf('fc-%s::configure',tbxfrom),'step 1')
      else
        warning(sprintf('fc-%s::configure',tbxfrom),'step 1')
      end
      failed=true;
    end
    rmpath(tbxpath);rehash path;
    if ~failed, return;end
  end
  failed=false;
  try % check if the toolbox is in current Matlab path
    eval(sprintf('fc_%s.version();',tbxname))
  catch
    fprintf('[fc-%s] Unable to load the fc-%s toolbox/package in current path\n',tbxfrom,tbxname)
    failed=true;
  end
  if ~failed, return;end
  failed=false;
  fullname=mfilename('fullpath');
  I=strfind(fullname,filesep);
  Path=fullname(1:(I(end-2)-1));
  
  lstdir=dir(Path); % try to guess directory. I don't use dir command due to trouble with octave
  C=arrayfun(@(x) x.name,lstdir, 'UniformOutput', false);
  I=strfind(C,['fc-',tbxname]);
  i=find(cellfun(@(x) ~isempty(x),I)==1);
  if ~isempty(i)
    k=1;
    while k<=length(i)
      tbxpath=[Path,filesep,C{i(k)}];
      addpath(tbxpath);rehash path;
      try % check if the toolbox is in new current Matlab path
        eval(sprintf('fc_%s.version();',tbxname))
      catch
        failed=true;
        fprintf('[fc-%s] Unable to load the fc-%s toolbox/package in guess path\n  %s\n',tbxfrom,tbxname,tbxpath)
        fprintf('[fc-%s] Use fc_%s.configure(''fc_%s_dir'',<DIR>) to correct this issue\n\n',tbxfrom,tbxfrom,tbxname);
        if stop
          error(sprintf('fc-%s::configure',tbxfrom),'step 2')
        else
          warning(sprintf('fc-%s::configure',tbxfrom),'step 2')
        end
      end
      rmpath(tbxpath);rehash path;
      if ~failed
        fprintf('[fc-%s] Loading the fc-%s toolbox/package in guess path\n  %s\n',tbxfrom,tbxname,tbxpath)
        return;
      end
      k=k+1;
    end
  else
    fprintf('[fc-%s] Guess path does not exists:\n   -> %s\n',tbxfrom,tbxname,tbxpath)
    fprintf('[fc-%s] Use fc_%s.configure(''fc_%s_dir'',<DIR>) to correct this issue\n\n',tbxfrom,tbxfrom,tbxname);
    if stop
      error(sprintf('fc-%s::configure',tbxfrom),'step 3')
    else
      warning(sprintf('fc-%s::configure',tbxfrom),'step 3')
    end
    failed=true;
  end
  if failed
      tbxpath='';
  else
    fprintf('[fc-%s] fc-%s toolbox/package found in path:\n   -> %s\n',tbxfrom,tbxname,tbxpath);
  end
end
